@@ -17,8 +17,8 @@ import tornado
 
 from bokeh.server.auth_provider import AuthProvider
 from tornado.auth import OAuth2Mixin
-from tornado.httpclient import HTTPError, HTTPRequest
-from tornado.web import RequestHandler, decode_signed_value
+from tornado.httpclient import HTTPError as HTTPClientError, HTTPRequest
+from tornado.web import HTTPError, RequestHandler, decode_signed_value
 from tornado.websocket import WebSocketHandler
 
 from .config import config
@@ -94,12 +94,14 @@ class OAuthLoginHandler(tornado.web.RequestHandler, OAuth2Mixin):
         'User-Agent': 'Tornado OAuth'
     }
 
-    _access_token_header = None
+    _DEFAULT_SCOPES = ['openid', 'email', 'profile', 'offline_access']
 
     _EXTRA_TOKEN_PARAMS = {
         'grant_type':    'authorization_code'
     }
 
+    _access_token_header = None
+
     _state_cookie = None
 
     _error_template = ERROR_TEMPLATE
@@ -111,7 +113,7 @@ class OAuthLoginHandler(tornado.web.RequestHandler, OAuth2Mixin):
         if 'scope' in config.oauth_extra_params:
             return config.oauth_extra_params['scope']
         elif 'PANEL_OAUTH_SCOPE' not in os.environ:
-            return ['openid', 'email', 'profile', 'offline_access']
+            return self._DEFAULT_SCOPES
         return [scope for scope in os.environ['PANEL_OAUTH_SCOPE'].split(',')]
 
     async def get_authenticated_user(self, redirect_uri, client_id, state,
@@ -216,30 +218,26 @@ class OAuthLoginHandler(tornado.web.RequestHandler, OAuth2Mixin):
         )
         try:
             response = await http.fetch(req)
-        except HTTPError as e:
+        except HTTPClientError as e:
             log.debug("%s access token request failed.", type(self).__name__)
-            self._on_error(e.response)
-            return None, None, None, None
+            self._raise_error(e.response, status=401)
 
-        body = decode_response_body(response)
-        if not body:
+        if not response.body or not (body:= decode_response_body(response)):
             log.debug("%s token endpoint did not return a valid access token.", type(self).__name__)
-            return
+            self._raise_error(response)
 
         if 'access_token' not in body:
             if refresh_token:
                 log.debug("%s token endpoint did not reissue an access token.", type(self).__name__)
                 return None, None, None
-            self._on_error(response, body)
-            return None, None, None, None
+            self._raise_error(response, body, status=401)
 
         access_token, refresh_token = body['access_token'], body.get('refresh_token')
         expires_in = body.get('expires_in')
         if expires_in:
             expires_in = int(expires_in)
-        if 'id_token' in body:
+        if id_token:= body.get('id_token'):
             log.debug("%s successfully obtained tokens.", type(self).__name__)
-            id_token = body['id_token']
             user = self._on_auth(id_token, access_token, refresh_token, expires_in)
             return user, access_token, refresh_token, expires_in
 
@@ -255,7 +253,7 @@ class OAuthLoginHandler(tornado.web.RequestHandler, OAuth2Mixin):
         try:
             user_response = await http.fetch(user_url, headers=user_headers)
             id_token = decode_response_body(user_response)
-        except HTTPError:
+        except HTTPClientError:
             id_token = None
 
         if not id_token:
@@ -264,8 +262,7 @@ class OAuthLoginHandler(tornado.web.RequestHandler, OAuth2Mixin):
                 id_token = decode_token(body['access_token'])
             except Exception:
                 log.debug("%s could not decode access_token.", type(self).__name__)
-                self._on_error(response, body)
-                return None, None, None, None
+                self._raise_error(response, body, status=401)
 
         log.debug("%s successfully obtained tokens.", type(self).__name__)
         user = self._on_auth(id_token, access_token, refresh_token, expires_in)
@@ -357,22 +354,14 @@ class OAuthLoginHandler(tornado.web.RequestHandler, OAuth2Mixin):
                 "%s failed to authenticate with following error: %s",
                 type(self).__name__, error
             )
-            self.set_header("Content-Type", 'text/html')
-            self.write(self._error_template.render(
-                npm_cdn=config.npm_cdn,
-                title='Panel: Authentication Error',
-                error_type='Authentication Error',
-                error=error,
-                error_msg=error_msg
-            ))
-            return
+            raise HTTPError(401, error_msg, reason=error)
 
         # Seek the authorization
         cookie_state = self.get_state_cookie()
         if code:
             if cookie_state != url_state:
                 log.warning("OAuth state mismatch: %s != %s", cookie_state, url_state)
-                raise HTTPError(400, "OAuth state mismatch")
+                raise HTTPError(401, "OAuth state mismatch. Please restart the authentication flow.", reason='state mismatch')
 
             state = _deserialize_state(url_state)
             # For security reason, the state value (cross-site token) will be
@@ -384,7 +373,7 @@ class OAuthLoginHandler(tornado.web.RequestHandler, OAuth2Mixin):
             })
             user = await self.get_authenticated_user(**params)
             if user is None:
-                raise HTTPError(403)
+                raise HTTPError(403, "Permissions unknown.")
             log.debug("%s authorized user, redirecting to app.", type(self).__name__)
             self.redirect(state.get('next_url', '/'))
         else:
@@ -405,7 +394,7 @@ class OAuthLoginHandler(tornado.web.RequestHandler, OAuth2Mixin):
         else:
             log.error("%s token payload did not contain expected %r.",
                       type(self).__name__, user_key)
-            raise HTTPError(400, "OAuth token payload missing user information")
+            raise HTTPError(401, "OAuth token payload missing user information")
         self.clear_cookie('is_guest')
         self.set_secure_cookie('user', user, expires_days=config.oauth_expiry)
         if state.encryption:
@@ -424,8 +413,7 @@ class OAuthLoginHandler(tornado.web.RequestHandler, OAuth2Mixin):
             state._oauth_user_overrides.pop(user, None)
         return user
 
-    def _on_error(self, response, body=None):
-        self.clear_all_cookies()
+    def _raise_error(self, response, body=None, status=400):
         try:
             body = body or decode_response_body(response)
         except json.decoder.JSONDecodeError:
@@ -438,13 +426,34 @@ class OAuthLoginHandler(tornado.web.RequestHandler, OAuth2Mixin):
             log.warning(f"{provider} OAuth provider failed to fully "
                         f"authenticate returning the following response:"
                         f"{body}.")
+        raise HTTPError(
+            status,
+            body.get('error_description', str(body)),
+            reason=body.get('error', 'Unknown error')
+        )
+
+    def write_error(self, status_code, **kwargs):
+        _, e, _ = kwargs['exc_info']
+        self.clear_all_cookies()
         self.set_header("Content-Type", 'text/html')
+        if isinstance(e, HTTPError):
+            error, error_msg = e.reason, e.log_message
+        else:
+            provider = self.__class__.__name__.replace('LoginHandler', '')
+            log.error(
+                f'{provider} OAuth provider encountered unexpected '
+                f'error: {e}'
+            )
+            error, error_msg = (
+                '500: Internal Server Error',
+                'Server encountered unexpected problem.'
+            )
         self.write(self._error_template.render(
             npm_cdn=config.npm_cdn,
             title='Panel: Authentication Error',
             error_type='Authentication Error',
-            error=body.get('error', 'Unknown Error'),
-            error_msg=body.get('error_description', body)
+            error=error,
+            error_msg=error_msg
         ))
 
 
@@ -758,10 +767,9 @@ class GoogleLoginHandler(OAuthLoginHandler):
     _API_BASE_HEADERS = {
         "Content-Type": "application/x-www-form-urlencoded; charset=utf-8"
     }
-
+    _DEFAULT_SCOPES = ['openid', 'email', 'profile']
     _OAUTH_AUTHORIZE_URL = "https://accounts.google.com/o/oauth2/v2/auth"
     _OAUTH_ACCESS_TOKEN_URL = "https://accounts.google.com/o/oauth2/token"
-
     _USER_KEY = 'email'
 
 
@@ -882,12 +890,14 @@ class BasicAuthProvider(AuthProvider):
         user_cookie = session_context.request.cookies.get('user')
         if guest_cookie:
             user = 'guest'
-        else:
+        elif user_cookie:
             user = decode_signed_value(
                 config.cookie_secret, 'user', user_cookie
             )
             if user:
                 user = user.decode('utf-8')
+        else:
+            user = None
         if not user:
             return
         state._active_users[user] -= 1
@@ -1024,8 +1034,20 @@ class OAuthProvider(BasicAuthProvider):
         return handler
 
     def _remove_user(self, session_context):
+        guest_cookie = session_context.request.cookies.get('is_guest')
         user_cookie = session_context.request.cookies.get('user')
-        user = decode_signed_value(config.cookie_secret, 'user', user_cookie).decode('utf-8')
+        if guest_cookie:
+            user = 'guest'
+        elif user_cookie:
+            user = decode_signed_value(
+                config.cookie_secret, 'user', user_cookie
+            )
+            if user:
+                user = user.decode('utf-8')
+        else:
+            user = None
+        if not user:
+            return
         state._active_users[user] -= 1
         if not state._active_users[user]:
             del state._active_users[user]
