@@ -7,6 +7,7 @@ through a frontend input UI.
 from __future__ import annotations
 
 from dataclasses import dataclass
+from functools import partial
 from io import BytesIO
 from typing import (
     Any, Callable, ClassVar, Dict, List,
@@ -50,6 +51,7 @@ class _ChatButtonData:
     icon: str
     objects: List
     buttons: List
+    callback: Callable
 
 
 class ChatInterface(ChatFeed):
@@ -104,6 +106,21 @@ class ChatInterface(ChatFeed):
         Widgets to use for the input. If not provided, defaults to
         `[TextInput]`.""")
 
+    button_properties = param.Dict(default={}, doc="""
+        Allows addition of functionality or customization of buttons
+        by supplying a mapping from the button name to a dictionary
+        containing the `icon`, `callback`, and/or `post_callback` keys.
+        If the button names correspond to default buttons
+        (send, rerun, undo, clear), the default icon can be
+        updated and if a `callback` key value pair is provided,
+        the specified callback functionality runs before the existing one.
+        For button names that don't match existing ones,
+        new buttons are created and must include a `callback` or `post_callback` key.
+        The provided callbacks should have a signature that accepts
+        two positional arguments: instance (the ChatInterface instance)
+        and event (the button click event).
+        """)
+
     _widgets = param.Dict(default={}, allow_refs=False, doc="""
         The input widgets.""")
 
@@ -129,21 +146,6 @@ class ChatInterface(ChatFeed):
         active = params.pop("active", None)
         super().__init__(*objects, **params)
 
-        button_icons = {
-            "send": "send",
-            "rerun": "repeat-once",
-            "undo": "arrow-back",
-            "clear": "trash",
-        }
-        for action in list(button_icons):
-            if not getattr(self, f"show_{action}", True):
-                button_icons.pop(action)
-        self._button_data = {
-            name: _ChatButtonData(
-                index=index, name=name, icon=icon, objects=[], buttons=[]
-            )
-            for index, (name, icon) in enumerate(button_icons.items())
-        }
         self._input_container = Row(
             css_classes=["chat-interface-input-container"],
             stylesheets=self._stylesheets,
@@ -175,7 +177,7 @@ class ChatInterface(ChatFeed):
         if self.show_button_name is None:
             self.show_button_name = self.width is None or self.width >= 400
 
-    @param.depends("widgets", watch=True)
+    @param.depends("widgets", "button_properties", watch=True)
     def _init_widgets(self):
         """
         Initialize the input widgets.
@@ -184,6 +186,42 @@ class ChatInterface(ChatFeed):
         -------
         The input widgets.
         """
+        default_button_properties = {
+            "send": {"icon": "send", "_default_callback": self._click_send},
+            "rerun": {"icon": "repeat", "_default_callback": self._click_rerun},
+            "undo": {"icon": "arrow-back", "_default_callback": self._click_undo},
+            "clear": {"icon": "trash", "_default_callback": self._click_clear},
+        }
+        self._allow_revert = len(self.button_properties) == 0
+
+        button_properties = {**default_button_properties, **self.button_properties}
+        for index, (name, properties) in enumerate(button_properties.items()):
+            name = name.lower()
+            callback = properties.get("callback")
+            post_callback = properties.get("post_callback")
+            default_properties = default_button_properties.get(name) or {}
+            if default_properties:
+                default_callback = default_properties["_default_callback"]
+                callback = (
+                    self._wrap_callbacks(callback=callback, post_callback=post_callback)(default_callback)
+                    if callback is not None else default_callback
+                )
+            elif callback is not None and post_callback is not None:
+                callback = self._wrap_callbacks(post_callback=post_callback)(callback)
+            elif callback is None and post_callback is not None:
+                callback = post_callback
+            elif callback is None and post_callback is None:
+                raise ValueError(f"A 'callback' key is required for the {name!r} button")
+            icon = properties.get("icon") or default_properties.get("icon")
+            self._button_data[name] = _ChatButtonData(
+                index=index,
+                name=name,
+                icon=icon,
+                objects=[],
+                buttons=[],
+                callback=callback,
+            )
+
         widgets = self.widgets
         if isinstance(self.widgets, Widget):
             widgets = [self.widgets]
@@ -230,6 +268,10 @@ class ChatInterface(ChatFeed):
             buttons = []
             for button_data in self._button_data.values():
                 action = button_data.name
+                try:
+                    visible = self.param[f'show_{action}']
+                except KeyError:
+                    visible = True
                 show_expr = self.param.show_button_name.rx()
                 button = Button(
                     name=show_expr.rx.where(button_data.name.title(), ""),
@@ -239,10 +281,11 @@ class ChatInterface(ChatFeed):
                     max_height=50,
                     margin=(5, 5, 5, 0),
                     align="start",
-                    visible=self.param[f'show_{action}']
+                    visible=visible
                 )
                 self._link_disabled_loading(button)
-                button.on_click(getattr(self, f"_click_{action}"))
+                callback = partial(button_data.callback, self)
+                button.on_click(callback)
                 buttons.append(button)
                 button_data.buttons.append(button)
 
@@ -263,7 +306,39 @@ class ChatInterface(ChatFeed):
         self._input_container.objects = [input_layout]
         self._input_layout = input_layout
 
-    def _click_send(self, _: param.parameterized.Event | None = None) -> None:
+    def _wrap_callbacks(
+            self,
+            callback: Callable | None = None,
+            post_callback: Callable | None = None
+        ):
+        """
+        Wrap the callback and post callback around the default callback.
+        """
+        def decorate(default_callback: Callable):
+            def wrapper(self, event: param.parameterized.Event):
+                if callback is not None:
+                    try:
+                        self.disabled = True
+                        callback(self, event)
+                    finally:
+                        self.disabled = False
+
+                default_callback(self, event)
+
+                if post_callback is not None:
+                    try:
+                        self.disabled = True
+                        post_callback(self, event)
+                    finally:
+                        self.disabled = False
+            return wrapper
+        return decorate
+
+    def _click_send(
+        self,
+        event: param.parameterized.Event | None = None,
+        instance: "ChatInterface" | None = None
+    ) -> None:
         """
         Send the input when the user presses Enter.
         """
@@ -334,7 +409,11 @@ class ChatInterface(ChatFeed):
             button_data.objects.clear()
             self._toggle_revert(button_data, False)
 
-    def _click_rerun(self, _):
+    def _click_rerun(
+        self,
+        event: param.parameterized.Event | None = None,
+        instance: "ChatInterface" | None = None
+    ) -> None:
         """
         Upon clicking the rerun button, rerun the last user message,
         which can trigger the callback again.
@@ -345,7 +424,11 @@ class ChatInterface(ChatFeed):
             return
         self.send(value=messages[0], respond=True)
 
-    def _click_undo(self, _):
+    def _click_undo(
+        self,
+        event: param.parameterized.Event | None = None,
+        instance: "ChatInterface" | None = None
+    ) -> None:
         """
         Upon clicking the undo button, undo (remove) messages
         up to the last user message. If the button is clicked
@@ -357,12 +440,19 @@ class ChatInterface(ChatFeed):
             self._reset_button_data()
             count = self._get_last_user_entry_index()
             undo_data.objects = self.undo(count)
-            self._toggle_revert(undo_data, True)
+            if self._allow_revert:
+                self._toggle_revert(undo_data, True)
+            else:
+                undo_data.objects = []
         else:
             self.extend(undo_objects)
             self._reset_button_data()
 
-    def _click_clear(self, _):
+    def _click_clear(
+        self,
+        event: param.parameterized.Event | None = None,
+        instance: "ChatInterface" | None = None
+    ) -> None:
         """
         Upon clicking the clear button, clear the chat log.
         If the button is clicked again without performing any
@@ -373,7 +463,10 @@ class ChatInterface(ChatFeed):
         if not clear_objects:
             self._reset_button_data()
             clear_data.objects = self.clear()
-            self._toggle_revert(clear_data, True)
+            if self._allow_revert:
+                self._toggle_revert(clear_data, True)
+            else:
+                clear_data.objects = []
         else:
             self[:] = clear_objects.copy()
             self._reset_button_data()
