@@ -31,6 +31,11 @@ class Convert(Subcommand):
             help    = "The format to convert to, one of 'pyodide' (default), 'pyodide-worker' or 'pyscript'",
             default = 'pyodide'
         )),
+        ('--compiled', dict(
+            default = False,
+            action  = 'store_false',
+            help    = "Whether to use the compiled and faster version of Pyodide."
+        )),
         ('--out', dict(
             action  = 'store',
             type    = str,
@@ -109,7 +114,8 @@ class Convert(Subcommand):
                     files, dest_path=args.out, runtime=runtime, requirements=requirements,
                     prerender=not args.skip_embed, build_index=index, build_pwa=args.pwa,
                     title=args.title, max_workers=args.num_procs,
-                    http_patch=not args.disable_http_patch, verbose=True
+                    http_patch=not args.disable_http_patch, compiled=args.compiled,
+                    verbose=True
                 )
             except KeyboardInterrupt:
                 print("Aborted while building docs.")
