@@ -147,6 +147,18 @@ class Serve(_BkServe):
             action  = 'store_true',
             help    = "Whether to automatically OAuth access tokens when they expire.",
         )),
+        ('--oauth-guest-endpoints', dict(
+            action  = 'store',
+            nargs   = '*',
+            help    = "List of endpoints that can be accessed as a guest without authenticating.",
+        )),
+        ('--oauth-optional', dict(
+            action  = 'store_true',
+            help    = (
+                "Whether the user will be forced to go through login flow "
+                "or if they can access all applications as a guest."
+            )
+        )),
         ('--login-endpoint', dict(
             action  = 'store',
             type    = str,
@@ -478,6 +490,11 @@ class Serve(_BkServe):
         else:
             error_template = None
 
+        if args.oauth_guest_endpoints:
+            config.oauth_guest_endpoints = args.oauth_guest_endpoints
+        if args.oauth_optional:
+            config.oauth_optional = args.oauth_optional
+
         if args.basic_auth:
             config.basic_auth = args.basic_auth
         if config.basic_auth:
@@ -485,7 +502,8 @@ class Serve(_BkServe):
                 login_endpoint=login_endpoint,
                 logout_endpoint=logout_endpoint,
                 login_template=login_template,
-                logout_template=logout_template
+                logout_template=logout_template,
+                guest_endpoints=config.oauth_guest_endpoints,
             )
 
         if args.cookie_secret and config.cookie_secret:
@@ -596,6 +614,7 @@ class Serve(_BkServe):
                 login_template=login_template,
                 logout_template=logout_template,
                 error_template=error_template,
+                guest_endpoints=config.oauth_guest_endpoints,
             )
 
             if args.oauth_redirect_uri and config.oauth_redirect_uri:
