@@ -191,7 +191,7 @@ class Vega(ModelPane):
 
     def _update_selections(self, *args):
         params = {
-            e: param.Dict() if stype == 'interval' else param.List()
+            e: param.Dict(allow_refs=False) if stype == 'interval' else param.List(allow_refs=False)
             for e, stype in self._selections.items()
         }
         if self.selection and (set(self.selection.param) - {'name'}) == set(params):
@@ -264,7 +264,7 @@ class Vega(ModelPane):
         data = props['data']
         if data is not None:
             sources = self._get_sources(data, sources)
-        dimensions = _get_dimensions(data)
+        dimensions = _get_dimensions(data) if data else {}
         props['data'] = data
         props['data_sources'] = sources
         props['events'] = list(self._selections)
