@@ -3,16 +3,17 @@ import pytest
 
 from bokeh.models import Column as BkColumn, Div, Row as BkRow
 
+from panel.chat import ChatInterface
 from panel.layout import (
     Accordion, Card, Column, Row, Spacer, Tabs, WidgetBox,
 )
 from panel.layout.base import ListPanel, NamedListPanel
-from panel.pane import Bokeh
+from panel.pane import Bokeh, Markdown
 from panel.param import Param
 from panel.tests.util import check_layoutable_properties
-from panel.widgets import Debugger
+from panel.widgets import Debugger, MultiSelect
 
-excluded = (NamedListPanel, Debugger)
+excluded = (NamedListPanel, Debugger, ChatInterface)
 all_panels = [w for w in param.concrete_descendents(ListPanel).values()
                if not w.__name__.startswith('_') and not issubclass(w, excluded)]
 
@@ -578,3 +579,22 @@ def test_column_scroll_params_sets_scroll(scroll_param, document, comm):
     col = Column(**params)
     assert getattr(col, scroll_param)
     assert col.scroll
+
+def test_pass_objects_ref(document, comm):
+    multi_select = MultiSelect(options=['foo', 'bar', 'baz'], value=['bar', 'baz'])
+    col = Column(objects=multi_select)
+    col.get_root(document, comm=comm)
+
+    assert len(col.objects) == 2
+    md1, md2 = col.objects
+    assert isinstance(md1, Markdown)
+    assert md1.object == 'bar'
+    assert isinstance(md2, Markdown)
+    assert md2.object == 'baz'
+
+    multi_select.value = ['foo']
+
+    assert len(col.objects) == 1
+    md3 = col.objects[0]
+    assert isinstance(md3, Markdown)
+    assert md3.object == 'foo'
