@@ -4,6 +4,8 @@ import pytest
 
 try:
     import plotly
+    import plotly.express as px
+    import plotly.figure_factory as ff
     import plotly.graph_objs as go
     import plotly.io as pio
     pio.templates.default = None
@@ -12,6 +14,7 @@ except Exception:
 plotly_available = pytest.mark.skipif(plotly is None, reason="requires plotly")
 
 import numpy as np
+import pandas as pd
 
 from panel.models.plotly import PlotlyPlot
 from panel.pane import PaneBase, Plotly
@@ -206,3 +209,34 @@ def test_clean_relayout_data():
         "mapbox.bearing": 0,
         "mapbox.pitch": 0,
     }
+
+
+@plotly_available
+def test_plotly_swap_traces(document, comm):
+    data_bar = pd.DataFrame({'Count': [1, 2, 3, 4], 'Category': ["A", "B", "C", "D"]})
+    data_cts = np.random.randn(1000)
+
+    bar_plot = px.bar(x=data_bar["Category"], y=data_bar["Count"])
+    dist_plot = ff.create_distplot(
+        [data_cts],
+        ["distplot"],
+        bin_size=0.5,
+        show_hist=False,
+        show_rug=False,
+        histnorm="probability",
+    )
+
+
+    plotly = Plotly(bar_plot)
+
+    model = plotly.get_root(document, comm)
+
+    assert len(model.data_sources) == 1
+    cds = model.data_sources[0]
+    assert (cds.data['x'] == data_bar.Category.values).all()
+    assert (cds.data['y'] == data_bar.Count.values).all()
+
+    plotly.object = dist_plot
+
+    assert 'x' not in cds.data
+    assert len(cds.data['y'][0]) == 500
