@@ -10,7 +10,6 @@ except Exception:
 
 altair_available = pytest.mark.skipif(alt is None, reason="requires altair")
 
-
 import numpy as np
 
 import panel as pn
@@ -21,6 +20,7 @@ from panel.pane import PaneBase, Vega
 blank_schema = {'$schema': ''}
 
 vega4_config = {'view': {'continuousHeight': 300, 'continuousWidth': 400}}
+vega5_config = {'view': {'continuousHeight': 300, 'continuousWidth': 300}}
 
 vega_example = {
     'config': {
@@ -38,6 +38,62 @@ vega_example = {
     '$schema': 'https://vega.github.io/schema/vega-lite/v3.2.1.json'
 }
 
+vega4_selection_example = {
+    'config': {'view': {'continuousWidth': 300, 'continuousHeight': 300}},
+    'data': {'url': 'https://raw.githubusercontent.com/vega/vega/master/docs/data/penguins.json'},
+    'mark': {'type': 'point'},
+    'encoding': {
+        'color': {
+            'condition': {
+                'selection': 'brush',
+                'field': 'Species',
+                'type': 'nominal'
+            },
+            'value': 'lightgray'},
+        'x': {
+            'field': 'Beak Length (mm)',
+            'scale': {'zero': False},
+            'type': 'quantitative'
+        },
+        'y': {
+            'field': 'Beak Depth (mm)',
+            'scale': {'zero': False},
+            'type': 'quantitative'}
+    },
+    'height': 250,
+    'selection': {'brush': {'type': 'interval'}},
+    'width': 250,
+    '$schema': 'https://vega.github.io/schema/vega-lite/v4.17.0.json'
+}
+
+vega5_selection_example = {
+    'config': {'view': {'continuousWidth': 300, 'continuousHeight': 300}},
+    'data': {'url': 'https://raw.githubusercontent.com/vega/vega/master/docs/data/penguins.json'},
+    'mark': {'type': 'point'},
+    'encoding': {
+        'color': {
+            'condition': {
+                'param': 'brush',
+                'field': 'Species',
+                'type': 'nominal'
+            },
+            'value': 'lightgray'},
+        'x': {
+            'field': 'Beak Length (mm)',
+            'scale': {'zero': False},
+            'type': 'quantitative'
+        },
+        'y': {
+            'field': 'Beak Depth (mm)',
+            'scale': {'zero': False},
+            'type': 'quantitative'}
+    },
+    'height': 250,
+    'params': [{'name': 'brush', 'select': {'type': 'interval'}}],
+    'width': 250,
+    '$schema': 'https://vega.github.io/schema/vega-lite/v5.6.1.json'
+}
+
 vega_inline_example = {
     'config': {
         'view': {'width': 400, 'height': 300},
@@ -190,6 +246,14 @@ def test_vega_pane_inline(document, comm):
     assert pane._models == {}
 
 
+def test_vega_lite_4_selection_spec(document, comm):
+    vega = Vega(vega4_selection_example)
+    assert vega._selections == {'brush': 'interval'}
+
+def test_vega_lite_5_selection_spec(document, comm):
+    vega = Vega(vega5_selection_example)
+    assert vega._selections == {'brush': 'interval'}
+
 def altair_example():
     import altair as alt
     data = alt.Data(values=[{'x': 'A', 'y': 5},
@@ -203,22 +267,23 @@ def altair_example():
     )
     return chart
 
-
 @altair_available
 def test_get_vega_pane_type_from_altair():
     assert PaneBase.get_pane_type(altair_example()) is Vega
 
-
 @altair_available
 def test_altair_pane(document, comm):
-    pane = pn.panel(altair_example())
+    pane = Vega(altair_example())
 
     # Create pane
     model = pane.get_root(document, comm=comm)
     assert isinstance(model, VegaPlot)
 
     expected = dict(vega_example, data={})
-    if altair_version >= Version('4.0.0'):
+    if altair_version >= Version('5.0.0rc1'):
+        expected['mark'] = {'type': 'bar'}
+        expected['config'] = vega5_config
+    elif altair_version >= Version('4.0.0'):
         expected['config'] = vega4_config
     assert dict(model.data, **blank_schema) == dict(expected, **blank_schema)
 
@@ -231,7 +296,10 @@ def test_altair_pane(document, comm):
     chart.data.values[0]['x'] = 'C'
     pane.object = chart
     point_example = dict(vega_example, data={},  mark='point')
-    if altair_version >= Version('4.0.0'):
+    if altair_version >= Version('5.0.0rc1'):
+        point_example['mark'] = {'type': 'point'}
+        point_example['config'] = vega5_config
+    elif altair_version >= Version('4.0.0'):
         point_example['config'] = vega4_config
     assert dict(model.data, **blank_schema) == dict(point_example, **blank_schema)
     cds_data = model.data_sources['data'].data
