@@ -1,15 +1,14 @@
 import pytest
 
-try:
-    from playwright.sync_api import expect
-except ImportError:
-    pytestmark = pytest.mark.skip('playwright not available')
+pytest.importorskip("playwright")
 
-pytestmark = pytest.mark.ui
+from playwright.sync_api import expect
 
 from panel.pane import Markdown
 from panel.tests.util import serve_component, wait_until
 
+pytestmark = pytest.mark.ui
+
 
 def test_update_markdown_pane(page):
     md = Markdown('Initial')
