@@ -1,40 +1,27 @@
-import time
-
 import pandas as pd
 import pytest
 
-from panel.io.server import serve
 from panel.pane import Perspective
-from panel.tests.util import wait_until
+from panel.tests.util import serve_component, wait_until
 
 pytestmark = pytest.mark.ui
 
-def test_perspective_no_console_errors(page, port):
+def test_perspective_no_console_errors(page):
     perspective = Perspective(pd._testing.makeMixedDataFrame())
-    serve(perspective, port=port, threaded=True, show=False)
 
-    msgs = []
-    page.on("console", lambda msg: msgs.append(msg))
+    msgs, _ = serve_component(page, perspective)
 
-    time.sleep(0.2)
-
-    page.goto(f"http://localhost:{port}")
-
-    time.sleep(1)
+    page.wait_for_timeout(1000)
 
     assert [msg for msg in msgs if msg.type == 'error' and 'favicon' not in msg.location['url']] == []
 
 
-def test_perspective_click_event(page, port):
+def test_perspective_click_event(page):
     events = []
     perspective = Perspective(pd._testing.makeMixedDataFrame())
     perspective.on_click(lambda e: events.append(e))
 
-    serve(perspective, port=port, threaded=True, show=False)
-
-    time.sleep(0.2)
-
-    page.goto(f"http://localhost:{port}")
+    serve_component(page, perspective)
 
     page.locator('tr').nth(3).click()
 
