@@ -51,9 +51,9 @@ from .input import (  # noqa
 from .misc import FileDownload, JSONEditor, VideoStream  # noqa
 from .player import DiscretePlayer, Player  # noqa
 from .select import (  # noqa
-    AutocompleteInput, CheckBoxGroup, CheckButtonGroup, CrossSelector,
-    MultiChoice, MultiSelect, RadioBoxGroup, RadioButtonGroup, Select,
-    ToggleGroup,
+    AutocompleteInput, CheckBoxGroup, CheckButtonGroup, ColorMap,
+    CrossSelector, MultiChoice, MultiSelect, RadioBoxGroup, RadioButtonGroup,
+    Select, ToggleGroup,
 )
 from .slider import (  # noqa
     DateRangeSlider, DateSlider, DatetimeRangeSlider, DiscreteSlider,
