@@ -11,6 +11,7 @@ from typing import (
 
 import param
 
+from param.parameterized import eval_function_with_deps, iscoroutinefunction
 from pyviz_comms import JupyterComm
 
 from ..io.notebook import push
@@ -207,21 +208,8 @@ class FileDownload(IconMixin):
         if self.embed:
             self._transfer()
 
-    @param.depends('_clicks', watch=True)
-    def _transfer(self):
-        if self.file is None and self.callback is None:
-            if self.embed:
-                raise ValueError('Must provide a file or a callback '
-                                 'if it is to be embedded.')
-            return
-
-        from ..param import ParamFunction
-        if self.callback is None:
-            fileobj = self.file
-        else:
-            fileobj = ParamFunction.eval(self.callback)
+    def _sync_data(self, fileobj):
         filename = self.filename
-
         if isinstance(fileobj, (str, Path)):
             fileobj = Path(fileobj)
             if not fileobj.exists():
@@ -259,6 +247,28 @@ class FileDownload(IconMixin):
         self._update_label()
         self._transfers += 1
 
+    async def _async_sync_data(self):
+        fileobj = await eval_function_with_deps(self.callback)
+        self._sync_data(fileobj)
+
+    @param.depends('_clicks', watch=True)
+    def _transfer(self):
+        if self.file is None and self.callback is None:
+            if self.embed:
+                raise ValueError('Must provide a file or a callback '
+                                 'if it is to be embedded.')
+            return
+
+        if self.callback is None:
+            fileobj = self.file
+        else:
+            if iscoroutinefunction(self.callback):
+                state.execute(self._async_sync_data)
+                return
+            else:
+                fileobj = eval_function_with_deps(self.callback)
+        self._sync_data(fileobj)
+
 
 
 class JSONEditor(Widget):
