@@ -234,7 +234,7 @@ class BaseTable(ReactiveData, Widget):
                 if not default_text_align:
                     msg = f"The 'text_align' in Tabulator.formatters[{col!r}] is overridden by Tabulator.text_align[{col!r}]"
                     warn(msg, RuntimeWarning)
-            elif col in self.indexes:
+            elif col in self.indexes and hasattr(formatter, "text_align"):
                 formatter.text_align = 'left'
 
             if isinstance(self.widths, int):
@@ -421,7 +421,7 @@ class BaseTable(ReactiveData, Widget):
         for col_name, filt in self._filters:
             if col_name is not None and col_name not in df.columns:
                 continue
-            if isinstance(filt, (FunctionType, MethodType)):
+            if isinstance(filt, (FunctionType, MethodType, partial)):
                 df = filt(df)
                 continue
             if isinstance(filt, param.Parameter):
@@ -561,7 +561,7 @@ class BaseTable(ReactiveData, Widget):
         """
         if isinstance(filter, (tuple, list, set)) or np.isscalar(filter):
             deps = []
-        elif isinstance(filter, (FunctionType, MethodType)):
+        elif isinstance(filter, (FunctionType, MethodType, partial)):
             deps = list(filter._dinfo['kw'].values()) if hasattr(filter, '_dinfo') else []
         else:
             filter = transform_reference(filter)
@@ -1537,11 +1537,7 @@ class Tabulator(BaseTable):
         elif events and all(e.name in page_events for e in events) and not self.pagination:
             self._processed, _ = self._get_data()
             return
-        elif (
-            self.pagination == 'remote'
-            and isinstance(self.selectable, str)
-            and "checkbox" in self.selectable
-        ):
+        elif self.pagination == 'remote':
             self._processed = None
         recompute = not all(
             e.name in ('page', 'page_size', 'pagination') for e in events
@@ -1615,8 +1611,8 @@ class Tabulator(BaseTable):
             ilocs = []
         else:  # SelectionEvent
             selected = indices.selected
+            ilocs = [] if indices.flush else self.selection.copy()
             indices = indices.indices
-            ilocs = self.selection
 
         nrows = self.page_size
         start = (self.page-1)*nrows
@@ -1629,9 +1625,12 @@ class Tabulator(BaseTable):
                 continue
             if selected:
                 ilocs.append(iloc)
-            else:
+            elif iloc in ilocs:
                 ilocs.remove(iloc)
-        self.selection = list(dict.fromkeys(ilocs))
+        ilocs = list(dict.fromkeys(ilocs))
+        if isinstance(self.selectable, int) and not isinstance(self.selectable, bool):
+            ilocs = ilocs[len(ilocs) - self.selectable:]
+        self.selection = ilocs
 
     def _get_properties(self, doc: Document) -> Dict[str, Any]:
         properties = super()._get_properties(doc)
